==> haskell-tasty-0.11.0.2-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-tasty/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty
version: 0.11.0.2
id: tasty-0.11.0.2-0e8cc58a9bca8b9b08149143caacc677
key: tasty_7egiDkMHbn3KsCupkTYRux
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: Modern and extensible testing framework
description:
    Tasty is a modern testing framework for Haskell.
    It lets you combine your unit tests, golden
    tests, QuickCheck/SmallCheck properties, and any
    other types of tests into a single test suite.
    See <http://documentup.com/feuerbach/tasty>.
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
exposed-modules:
    Test.Tasty Test.Tasty.Options Test.Tasty.Providers
    Test.Tasty.Runners Test.Tasty.Ingredients
    Test.Tasty.Ingredients.Basic
hidden-modules: Test.Tasty.Parallel Test.Tasty.Core
                Test.Tasty.Options.Core Test.Tasty.Options.Env Test.Tasty.Patterns
                Test.Tasty.Run Test.Tasty.Runners.Reducers Test.Tasty.Runners.Utils
                Test.Tasty.CmdLine Test.Tasty.Ingredients.ConsoleReporter
                Test.Tasty.Ingredients.ListTests
                Test.Tasty.Ingredients.IncludingOptions
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-0.11.0.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-0.11.0.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/tasty-0.11.0.2
hs-libraries: HStasty-0.11.0.2-7egiDkMHbn3KsCupkTYRux
depends:
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    clock-0.6.0.1-713f6913c58d4b0a7d37f9b31c87f350
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
    regex-tdfa-1.2.1-2f2ff40a952b63109ef37be1ffea97d0
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    unbounded-delays-0.1.0.9-d8d3d98a397b27cddff9df391347a222
haddock-interfaces: /usr/share/doc/haskell-tasty/html/tasty.haddock
haddock-html: /usr/share/doc/haskell-tasty/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-0.11.0.2-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-tasty/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty
version: 0.11.0.2
id: tasty-0.11.0.2-6ecf5c4c4584053c63756484aea2d9b8
key: tasty_JSYm4uWxjRl3xRla4ZuZwZ
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: Modern and extensible testing framework
description:
    Tasty is a modern testing framework for Haskell.
    It lets you combine your unit tests, golden
    tests, QuickCheck/SmallCheck properties, and any
    other types of tests into a single test suite.
    See <http://documentup.com/feuerbach/tasty>.
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
exposed-modules:
    Test.Tasty Test.Tasty.Options Test.Tasty.Providers
    Test.Tasty.Runners Test.Tasty.Ingredients
    Test.Tasty.Ingredients.Basic
hidden-modules: Test.Tasty.Parallel Test.Tasty.Core
                Test.Tasty.Options.Core Test.Tasty.Options.Env Test.Tasty.Patterns
                Test.Tasty.Run Test.Tasty.Runners.Reducers Test.Tasty.Runners.Utils
                Test.Tasty.CmdLine Test.Tasty.Ingredients.ConsoleReporter
                Test.Tasty.Ingredients.ListTests
                Test.Tasty.Ingredients.IncludingOptions
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-0.11.0.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/tasty-0.11.0.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/tasty-0.11.0.2
hs-libraries: HStasty-0.11.0.2-JSYm4uWxjRl3xRla4ZuZwZ
depends:
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    clock-0.6.0.1-713f6913c58d4b0a7d37f9b31c87f350
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
    regex-tdfa-1.2.1-506e9a407febb132e40b4c629d403ead
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    unbounded-delays-0.1.0.9-d8d3d98a397b27cddff9df391347a222
haddock-interfaces: /usr/share/doc/haskell-tasty/html/tasty.haddock
haddock-html: /usr/share/doc/haskell-tasty/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
